
<div align="center">
  <img src="https://blogs.cappriciosec.com/uploaders/CVE-2000-0114-tool.png" alt="logo">
</div>


## Badges



[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)
![PyPI - Version](https://img.shields.io/pypi/v/CVE-2000-0114)
![PyPI - Downloads](https://img.shields.io/pypi/dm/CVE-2000-0114)
![GitHub all releases](https://img.shields.io/github/downloads/Cappricio-Securities/CVE-2000-0114/total)
<a href="https://github.com/Cappricio-Securities/CVE-2000-0114/releases/"><img src="https://img.shields.io/github/release/Cappricio-Securities/CVE-2000-0114"></a>![Profile_view](https://komarev.com/ghpvc/?username=Cappricio-Securities&label=Profile%20views&color=0e75b6&style=flat)
[![Follow Twitter](https://img.shields.io/twitter/follow/cappricio_sec?style=social)](https://twitter.com/cappricio_sec)
<p align="center">

<p align="center">







## License

[MIT](https://choosealicense.com/licenses/mit/)



## Installation 

1. Install Python3 and pip [Instructions Here](https://www.python.org/downloads/) (If you can't figure this out, you shouldn't really be using this)

   - Install via pip
     - ```bash
          pip install CVE-2000-0114 
        ```
   - Run bellow command to check
     - `CVE-2000-0114 -h`

## Configurations 
2. We integrated with the Telegram API to receive instant notifications for vulnerability detection.
   
   - Telegram Notification
     - ```bash
          CVE-2000-0114 --chatid <YourTelegramChatID>
        ```
   - Open your telegram and search for [`@CappricioSecuritiesTools_bot`](https://web.telegram.org/k/#@CappricioSecuritiesTools_bot) and click start

## Usages 
3. This tool has multiple use cases.
   
   - To Check Single URL
     - ```bash
          CVE-2000-0114 -u http://example.com 
        ```
   - To Check List of URL 
      - ```bash
          CVE-2000-0114 -i urls.txt 
        ```
   - Save output into TXT file
      - ```bash
          CVE-2000-0114 -i urls.txt -o out.txt
        ```
   - Want to Learn about [`CVE-2000-0114`](https://blogs.cappriciosec.com/blog/173/CVE-2000-0114)? Then Type Below command
      - ```bash
          CVE-2000-0114 -b
        ```
     
<p align="center">
  <b>🚨 Disclaimer</b>
  
</p>
<p align="center">
<b>This tool is created for security bug identification and assistance; Cappricio Securities is not liable for any illegal use. 
  Use responsibly within legal and ethical boundaries. 🔐🛡️</b></p>


## Working PoC Video

[![asciicast](https://blogs.cappriciosec.com/uploaders/Screenshot%202024-06-03%20at%2012.51.57%20PM.png)](https://asciinema.org/a/GCcvohSDzAkG0hzUC02Q5jQHx)




## Help menu

#### Get all items

```bash
👋 Hey Hacker
                                                                             v1.0
   _______    ________    ___   ____  ____  ____        ____ ________ __
  / ____/ |  / / ____/   |__ \ / __ \/ __ \/ __ \      / __ <  <  / // /
 / /    | | / / __/________/ // / / / / / / / / /_____/ / / / // / // /_
/ /___  | |/ / /__/_____/ __// /_/ / /_/ / /_/ /_____/ /_/ / // /__  __/
\____/  |___/_____/    /____/\____/\____/\____/      \____/_//_/  /_/

                              Developed By https://cappriciosec.com


CVE-2000-0114 : Bug scanner for WebPentesters and Bugbounty Hunters 

$ CVE-2000-0114 [option]

Usage: CVE-2000-0114 [options]
```


| Argument | Type     | Description                | Examples |
| :-------- | :------- | :------------------------- | :------------------------- |
| `-u` | `--url` | URL to scan | CVE-2000-0114 -u https://target.com |
| `-i` | `--input` | filename Read input from txt  | CVE-2000-0114 -i target.txt | 
| `-o` | `--output` | filename Write output in txt file | CVE-2000-0114 -i target.txt -o output.txt |
| `-c` | `--chatid` | Creating Telegram Notification | CVE-2000-0114 --chatid yourid |
| `-b` | `--blog` | To Read about CVE-2000-0114 Bug | CVE-2000-0114 -b |
| `-h` | `--help` | Help Menu | CVE-2000-0114 -h |



## 🔗 Links
[![Website](https://img.shields.io/badge/my_portfolio-000?style=for-the-badge&logo=ko-fi&logoColor=white)](https://cappriciosec.com/)
[![linkedin](https://img.shields.io/badge/linkedin-0A66C2?style=for-the-badge&logo=linkedin&logoColor=white)](https://www.linkedin.com/in/karthikeyan--v/)
[![twitter](https://img.shields.io/badge/twitter-1DA1F2?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/karthithehacker)



## Author

- [@karthithehacker](https://github.com/karthi-the-hacker/)



## Feedback

If you have any feedback, please reach out to us at contact@karthithehacker.com
